@@ -25,7 +25,10 @@ OC.L10N.register(
     "Message sent!" : "Boodskap gestuur!",
     "Send" : "Stuur",
     "Select" : "Kies",
+    "Move" : "Skuif",
     "Delete" : "Skrap",
+    "Choose target folder" : "Kies teikenvouer",
+    "Choose" : "Kies",
     "Important" : "Belangrik",
     "Favorites" : "Gunstelinge",
     "Other" : "Ander",
