@@ -52,8 +52,12 @@ OC.L10N.register(
     "Mark read" : "Маркирай като прочетено",
     "Unselect" : "Размаркирай",
     "Select" : "Избери",
+    "Move" : "Преместване",
     "Delete" : "Изтриване",
     "Loading messages" : "Зареждане на съобщенията",
+    "Choose target folder" : "Избор на папка",
+    "No more subfolders in here" : "Няма подпапки",
+    "Choose" : "Изберете",
     "Important" : "Важно",
     "Favorites" : "Любими",
     "Other" : "Друг",
