@@ -9,7 +9,9 @@ OC.L10N.register(
     "Save" : "Spremi",
     "Send" : "Pošalji",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "Obriši",
+    "Choose" : "Izaberite",
     "Important" : "Važno",
     "Favorites" : "Favoriti",
     "Other" : "Ostali",
