@@ -37,7 +37,9 @@ OC.L10N.register(
     "Mark read" : "Mark read",
     "Unselect" : "Unselect",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "Delete",
+    "Choose" : "Choose",
     "Important" : "Important",
     "Favorites" : "Favourites",
     "Other" : "Other",
