@@ -67,12 +67,16 @@ OC.L10N.register(
     "Mark read" : "Marki kiel legita",
     "Unselect" : "Malelekti",
     "Select" : "Elekti",
+    "Move" : "Movi",
     "Delete" : "Forigi",
     "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
     "Report this bug" : "Raporti tiun problemon",
     "Could not open mailbox" : "Ne eblis malfermi poŝtkesto",
     "Loading messages" : "Ŝargas mesaĝojn",
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksas viajn mesaĝojn. Tio eble daŭrus iom pli longe por pli grandaj poŝtkestoj.",
+    "Choose target folder" : "Elekti celan dosierujon",
+    "No more subfolders in here" : "Ne plu estas subdosierujo ĉi tie.",
+    "Choose" : "Elekti",
     "Important" : "Grava",
     "Favorites" : "Pliŝataĵoj",
     "Other" : "Alia",
