@@ -34,7 +34,9 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
     "Mark read" : "Marcar como leído",
     "Select" : "Seleccionar",
+    "Move" : "Mover",
     "Delete" : "Borrar",
+    "Choose" : "Seleccionar",
     "Important" : "Importante",
     "Favorites" : "Favoritos",
     "Other" : "Otro",
