@@ -36,7 +36,9 @@ OC.L10N.register(
     "No messages in this folder" : "No hay mensajes en esta carpeta",
     "Mark read" : "Marcar como leído",
     "Select" : "Seleccionar",
+    "Move" : "Mover",
     "Delete" : "Borrar",
+    "Choose" : "Seleccionar",
     "Important" : "Importante",
     "Favorites" : "Favoritos",
     "Other" : "Otro",
