@@ -8,7 +8,9 @@ OC.L10N.register(
     "Connect" : "Միանալ",
     "Send" : "Ուղարկել",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "հեռացնել",
+    "Choose" : "Ընտրել",
     "Favorites" : "Favorites",
     "Other" : "Այլ",
     "Settings" : "կարգավորումներ",
