@@ -26,7 +26,9 @@ OC.L10N.register(
     "Message sent!" : "зурвас илгээсэн",
     "Send" : "илгээх",
     "Select" : "Сонгох",
+    "Move" : "Зөөх",
     "Delete" : "Устгах",
+    "Choose" : "Сонгох",
     "Favorites" : "Онцолсон",
     "Other" : "Бусад",
     "Attachments" : "Хавсралт",
