@@ -10,7 +10,9 @@ OC.L10N.register(
     "Retry" : "Forsøk att",
     "Send" : "Send",
     "Select" : "Vel",
+    "Move" : "Move",
     "Delete" : "Ta bort",
+    "Choose" : "Vel",
     "Important" : "Viktig",
     "Favorites" : "Favorit",
     "Other" : "Anna",
