@@ -15,7 +15,9 @@ OC.L10N.register(
     "Send" : "Mandar",
     "Choose a file to add as attachment" : "Causissètz un fichièr de jónher al messatge",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "Suprimir",
+    "Choose" : "Causir",
     "Important" : "Important",
     "Favorites" : "Favorits",
     "Other" : "Autre",
