@@ -8,7 +8,11 @@ OC.L10N.register(
     "Send" : "لېږل",
     "Unselect" : "سشیبشسیب",
     "Select" : "ټاکل",
+    "Move" : "انتقال",
     "Delete" : "ړنګول",
+    "Choose target folder" : "د ورانتقالېدو فولډر ټاکل",
+    "No more subfolders in here" : "منځ فولډر نشته",
+    "Choose" : "غوره کړئ",
     "Favorites" : "په نښه شوي",
     "Other" : "نور",
     "Settings" : "سمونې",
