@@ -30,7 +30,10 @@ OC.L10N.register(
     "Mark unread" : "Marcar como não lido",
     "Mark read" : "Marcar como lido",
     "Select" : "Seleccionar",
+    "Move" : "Mover",
     "Delete" : "Eliminar",
+    "No more subfolders in here" : "Atualmente não há sub-pastas aqui",
+    "Choose" : "Escolher",
     "Important" : "Importante",
     "Favorites" : "Favoritos",
     "Other" : "Outro",
