@@ -8,7 +8,9 @@ OC.L10N.register(
     "Save" : "සුරකින්න",
     "Connect" : "සම්බන්ධ වන්න",
     "Select" : "Select",
+    "Move" : "Move",
     "Delete" : "ඉවත් කරන්න",
+    "Choose" : "තෝරන්න",
     "Important" : "වැදගත්",
     "Favorites" : "Favorites",
     "Other" : "වෙනත්",
