@@ -7,7 +7,9 @@ OC.L10N.register(
     "Save" : "Saqlash",
     "Connect" : "Ulanmoq",
     "Send" : "Yuborish",
+    "Move" : "Ko'chiring",
     "Delete" : "O'chir",
+    "Choose" : "Tanlang",
     "Settings" : "Sozlamalar",
     "Saving" : "Saqlanmoqda",
     "Cancel" : "Bekor qilish",
