@@ -25,16 +25,22 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Db;
 
+use Horde_Mail_Rfc822_Identification;
 use JsonSerializable;
 use OCA\Mail\AddressList;
 use OCP\AppFramework\Db\Entity;
 use function in_array;
+use function json_decode;
+use function json_encode;
 
 /**
  * @method void setUid(int $uid)
  * @method int getUid()
- * @method void setMessageId(string $id)
  * @method string getMessageId()
+ * @method void setReferences(string $references)
+ * @method string|null getReferences()
+ * @method string|null getInReplyTo()
+ * @method string|null getThreadRootId()
  * @method void setMailboxId(int $mailbox)
  * @method int getMailboxId()
  * @method void setSubject(string $subject)
@@ -83,6 +89,9 @@ class Message extends Entity implements JsonSerializable {
 
 	protected $uid;
 	protected $messageId;
+	protected $references;
+	protected $inReplyTo;
+	protected $threadRootId;
 	protected $mailboxId;
 	protected $subject;
 	protected $sentAt;
@@ -119,6 +128,7 @@ class Message extends Entity implements JsonSerializable {
 		$this->bcc = new AddressList([]);
 
 		$this->addType('uid', 'integer');
+		$this->addType('mailboxId', 'integer');
 		$this->addType('sentAt', 'integer');
 		$this->addType('flagAnswered', 'bool');
 		$this->addType('flagDeleted', 'bool');
@@ -134,6 +144,28 @@ class Message extends Entity implements JsonSerializable {
 		$this->addType('updatedAt', 'integer');
 	}
 
+	public function setMessageId(?string $messageId): void {
+		$this->setMessageIdFieldIfNotEmpty('messageId', $messageId);
+	}
+
+	public function setRawReferences(?string $references): void {
+		$parsed = new Horde_Mail_Rfc822_Identification($references);
+		$this->setter('references', [json_encode($parsed->ids)]);
+	}
+
+	public function setInReplyTo(?string $inReplyTo): void {
+		$this->setMessageIdFieldIfNotEmpty('inReplyTo', $inReplyTo);
+	}
+
+	public function setThreadRootId(?string $messageId): void {
+		$this->setMessageIdFieldIfNotEmpty('threadRootId', $messageId);
+	}
+
+	private function setMessageIdFieldIfNotEmpty(string $field, ?string $id): void {
+		$parsed = new Horde_Mail_Rfc822_Identification($id);
+		$this->setter($field, [$parsed->ids[0] ?? null]);
+	}
+
 	/**
 	 * @return AddressList
 	 */
@@ -204,7 +236,8 @@ class Message extends Entity implements JsonSerializable {
 
 	public function jsonSerialize() {
 		return [
-			'id' => $this->getUid(), // Change to UID on front-end
+			'databaseId' => $this->getId(),
+			'uid' => $this->getUid(),
 			'subject' => $this->getSubject(),
 			'dateInt' => $this->getSentAt(),
 			'flags' => [
@@ -222,6 +255,11 @@ class Message extends Entity implements JsonSerializable {
 			'to' => $this->getTo()->jsonSerialize(),
 			'cc' => $this->getCc()->jsonSerialize(),
 			'bcc' => $this->getBcc()->jsonSerialize(),
+			'mailboxId' => $this->getMailboxId(),
+			'messageId' => $this->getMessageId(),
+			'inReplyTo' => $this->getInReplyTo(),
+			'references' => empty($this->getReferences()) ? null: json_decode($this->getReferences(), true),
+			'threadRootId' => $this->getThreadRootId(),
 		];
 	}
 }
