@@ -34,7 +34,6 @@ use OCA\Mail\Db\Message;
 use OCA\Mail\Events\DraftSavedEvent;
 use OCA\Mail\Events\MessageSentEvent;
 use OCA\Mail\IMAP\IMAPClientFactory;
-use OCA\Mail\IMAP\MailboxSync;
 use OCA\Mail\IMAP\MessageMapper;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\EventDispatcher\Event;
@@ -52,21 +51,16 @@ class DeleteDraftListener implements IEventListener {
 	/** @var MessageMapper */
 	private $messageMapper;
 
-	/** @var MailboxSync */
-	private $mailboxSync;
-
 	/** @var LoggerInterface */
 	private $logger;
 
 	public function __construct(IMAPClientFactory $imapClientFactory,
 								MailboxMapper $mailboxMapper,
 								MessageMapper $messageMapper,
-								MailboxSync $mailboxSync,
 								LoggerInterface $logger) {
 		$this->imapClientFactory = $imapClientFactory;
 		$this->mailboxMapper = $mailboxMapper;
 		$this->messageMapper = $messageMapper;
-		$this->mailboxSync = $mailboxSync;
 		$this->logger = $logger;
 	}
 
@@ -84,7 +78,12 @@ class DeleteDraftListener implements IEventListener {
 	 */
 	private function deleteDraft(Account $account, Message $draft): void {
 		$client = $this->imapClientFactory->getClient($account);
-		$draftsMailbox = $this->getDraftsMailbox($account);
+		try {
+			$draftsMailbox = $this->getDraftsMailbox($account);
+		} catch (DoesNotExistException $e) {
+			$this->logger->warning("Account has no draft mailbox set, can't delete the draft");
+			return;
+		}
 
 		try {
 			$this->messageMapper->addFlag(
@@ -108,38 +107,14 @@ class DeleteDraftListener implements IEventListener {
 		}
 	}
 
+	/**
+	 * @throws DoesNotExistException
+	 */
 	private function getDraftsMailbox(Account $account): Mailbox {
-		try {
-			return $this->mailboxMapper->findSpecial($account, 'drafts');
-		} catch (DoesNotExistException $e) {
-			$this->logger->debug('Creating drafts mailbox');
-			$this->createDraftsMailbox($account);
-			$this->logger->debug('Drafts mailbox created');
+		$draftsMailboxId = $account->getMailAccount()->getDraftsMailboxId();
+		if ($draftsMailboxId === null) {
+			throw new DoesNotExistException("No drafts mailbox ID set");
 		}
-
-		return $this->mailboxMapper->findSpecial($account, 'drafts');
-	}
-
-	private function createDraftsMailbox(Account $account): void {
-		$client = $this->imapClientFactory->getClient($account);
-
-		try {
-			// TODO: localize mailbox name
-			$client->createMailbox(
-				'Drafts',
-				[
-					'special_use' => [
-						\Horde_Imap_Client::SPECIALUSE_DRAFTS,
-					],
-				]
-			);
-		} catch (Horde_Imap_Client_Exception $e) {
-			$this->logger->error('Could not create drafts mailbox', [
-				'exception' => $e,
-			]);
-		}
-
-		// TODO: find a more elegant solution for updating the mailbox cache
-		$this->mailboxSync->sync($account, $this->logger,true);
+		return $this->mailboxMapper->findById($draftsMailboxId);
 	}
 }
