@@ -23,20 +23,20 @@ declare(strict_types=1);
 
 namespace OCA\Mail\Service\AutoConfig;
 
-use OCP\ILogger;
+use Psr\Log\LoggerInterface;
 
 class MxRecord {
 
-	/** @var ILogger */
+	/** @var LoggerInterface */
 	private $logger;
 
-	public function __construct(ILogger $logger) {
+	public function __construct(LoggerInterface $logger) {
 		$this->logger = $logger;
 	}
 
 	/**
 	 * @param $host
-	 * @return bool|array
+	 * @return false|array
 	 */
 	public function query(string $host) {
 		if (getmxrr($host, $mxRecords, $mxWeight) === false) {
