@@ -246,8 +246,13 @@ class ImportanceClassifier {
 	 */
 	private function getOutgoingMailboxes(Account $account): array {
 		try {
+			$sentMailboxId = $account->getMailAccount()->getSentMailboxId();
+			if ($sentMailboxId === null) {
+				return [];
+			}
+
 			return [
-				$this->mailboxMapper->findSpecial($account, 'sent')
+				$this->mailboxMapper->findById($sentMailboxId)
 			];
 		} catch (DoesNotExistException $e) {
 			return [];
@@ -352,6 +357,7 @@ class ImportanceClassifier {
 										array $trainingSet,
 										array $validationSet,
 										LoggerInterface $logger): Classifier {
+		/** @var float[] $predictedValidationLabel */
 		$predictedValidationLabel = $estimator->predict(Unlabeled::build(
 			array_column($validationSet, 'features')
 		));
